version = "0.0.25"
author = "RedHog (Egil Moeller)"
author_email = "egil.moller@freecode.no"
license = "GPL"
url = "http://github.com/redhog/appomatic"
name = "appomatic_appadmin"
description = "Django admin page to administer appomatic apps"
keywords = "appomatic django-admin"
install_requires = ['appomatic_admin=='+version]
